@@ -36,7 +36,7 @@ pub fn build_cli() -> Command<'static> {
             .min_values(1)
             .multiple_occurrences(true)
             .short('f')
-            .possible_values(&["info", "debug", "warning", "error", "info", "fatal", "panic", "dpanic"])
+            .possible_values(&["info", "debug", "warning", "error", "info"])
             .long("filter-levels"),
         )
         .arg(
@@ -57,6 +57,8 @@ pub fn build_cli() -> Command<'static> {
         .arg(
             Arg::new("level-symbols")
                 .long("level-symbols")
+                .long_help("This will replace the level with a pretty emoji instead of the label.\n\
+                You can set the enviroment variable `SNAZY_LEVEL_SYMBOLS` to always have it.\n")
                 .help("Replace log level with pretty symbols")
         )
         .arg(
@@ -75,6 +77,18 @@ pub fn build_cli() -> Command<'static> {
                     from the (`message`, `level`, `ts`) json keys."
                 ),
         )
+        .arg(
+            Arg::new("files")
+                .multiple_occurrences(true)
+                .help("files to read, if not specified, stdin is used")
+                .takes_value(true)
+                .long_help(
+                    "Specify one or multiple files to read.\n\
+                    If no files are specified, stdin is used.\n\
+                    If no files are specified and stdin is not a tty, stdin is used.\n\
+                    If no files are specified and stdin is a tty, stdin is used."
+                )
+        )
         .arg(
             Arg::new("color")
                 .long("color")
